set_task!() { /* proc-macro */ }Expand description
Assigns a task closure to an existing task source by expanding to a
set_task_fn call on the given target with the supplied closure.
set_task!() { /* proc-macro */ }Assigns a task closure to an existing task source by expanding to a
set_task_fn call on the given target with the supplied closure.