task!() { /* proc-macro */ }Expand description
Constructs a workflow_task::Task from a closure or expression, wrapping
the closure body so it is boxed and pinned as the task’s async future.
task!() { /* proc-macro */ }Constructs a workflow_task::Task from a closure or expression, wrapping
the closure body so it is boxed and pinned as the task’s async future.