TaskFn

Type Alias TaskFn 

pub type TaskFn<A, T> = Arc<Box<dyn Send + Sync + Fn(A, Receiver<()>) -> FnReturn<T> + 'static>>;
Boxed async closure executed by a Task, receiving the task argument and a termination Receiver and returning the task’s future via FnReturn.

Aliased Type

pub struct TaskFn<A, T> { /* private fields */ }